@@ -1,17 +1,12 @@
 #include <skalibs/random.h>
 
 int main() {
-  unsigned char c;
   uint32_t max = 100;
   uint32_t n;
   size_t b = 100;
   char data[100];
-  int r;
 
-  r = random_init();
-  c = random_char();
   n = random_uint32(max);
-  random_string(data, b);
-  random_finish();
+  random_buf(data, b);
   return 0;
 }
